==> mshow-model-1.0.0.0-20181225.015830-4-sources.jar: com/mini/mshow/model/dbto/site/SubjectAlbumPhotoDbto.java <==
package com.mini.mshow.model.dbto.site;

import com.mini.framework.model.dbto.style1.DbtoIntEntity;
import com.mini.framework.model.role.write.Insertable;
import com.mini.framework.model.role.write.Updatable;

/**
 * 某相册的相片
 * @author jayheo
 *
 */
public class SubjectAlbumPhotoDbto extends DbtoIntEntity {

	/**
	 * 
	 */
	private static final long serialVersionUID = 6149160031081726843L;

	
	@Insertable(require="相片标题")
	@Updatable(suffice="相片标题")
	private String title;
	
	/**
	 * 拥有者id 冗余这个数字反正不会变的
	 * 也是就作者
	 */
	@Insertable(require="相片作者")
	@Updatable(forbid="相片作者")
	private Integer authorId;

	/**
	 * 相册id 冗余这个数字反正不会变的
	 */
	@Insertable(require="相片所属相册")
	@Updatable(forbid="相片所属相册")
	private Integer albumId;

	/**
	 * 相册资源的地址
	 */
	@Insertable(require="相片资源地址")
	@Updatable(forbid="相片资源地址")
	private String resUrl;
	
	/**
	 * 资源id
	 */
	@Updatable(forbid="相片资源id")
	private Integer resourseId;

	// TODO 要把标签值和标签数弄出来

	public Integer getAlbumId() {
		return albumId;
	}

	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public Integer getAuthorId() {
		return authorId;
	}

	public void setAuthorId(Integer authorId) {
		this.authorId = authorId;
	}

	public void setAlbumId(Integer albumId) {
		this.albumId = albumId;
	}

	public String getResUrl() {
		return resUrl;
	}

	public void setResUrl(String resUrl) {
		this.resUrl = resUrl;
	}

	public Integer getResourseId() {
		return resourseId;
	}

	public void setResourseId(Integer resourseId) {
		this.resourseId = resourseId;
	}
	
	

}

==> mshow-model-1.0.0.0-20181226.023904-8-sources.jar: com/mini/mshow/model/dbto/site/SubjectAlbumPhotoDbto.java <==
package com.mini.mshow.model.dbto.site;

import com.mini.framework.model.dbto.style1.DbtoIntEntity;
import com.mini.framework.model.role.write.Insertable;
import com.mini.framework.model.role.write.Updatable;

/**
 * 某相册的相片
 * @author jayheo
 *
 */
public class SubjectAlbumPhotoDbto extends DbtoIntEntity {

	/**
	 * 
	 */
	private static final long serialVersionUID = 6149160031081726843L;

	
	@Insertable(require="相片标题",minLength=2,maxLength=2000)
	@Updatable(suffice="相片标题",minLength=2,maxLength=2000)
	private String title;
	
	/**
	 * 拥有者id 冗余这个数字反正不会变的
	 * 也是就作者
	 */
	@Insertable(require="相片作者")
	@Updatable(forbid="相片作者")
	private Integer authorId;

	/**
	 * 相册id 冗余这个数字反正不会变的
	 */
	@Insertable(require="相片所属相册")
	@Updatable(forbid="相片所属相册")
	private Integer albumId;

	/**
	 * 相册资源的地址
	 */
	@Insertable(require="相片资源地址")
	@Updatable(forbid="相片资源地址")
	private String resUrl;
	
	/**
	 * 资源id
	 */
	@Updatable(forbid="相片资源id")
	private Integer resourseId;

	// TODO 要把标签值和标签数弄出来

	public Integer getAlbumId() {
		return albumId;
	}

	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public Integer getAuthorId() {
		return authorId;
	}

	public void setAuthorId(Integer authorId) {
		this.authorId = authorId;
	}

	public void setAlbumId(Integer albumId) {
		this.albumId = albumId;
	}

	public String getResUrl() {
		return resUrl;
	}

	public void setResUrl(String resUrl) {
		this.resUrl = resUrl;
	}

	public Integer getResourseId() {
		return resourseId;
	}

	public void setResourseId(Integer resourseId) {
		this.resourseId = resourseId;
	}
	
	

}
